package WebService::Braintree::Transaction::CreatedUsing;
$WebService::Braintree::Transaction::CreatedUsing::VERSION = '0.94';
use 5.010_001;
use strictures 1;

use constant Token => "token";
use constant FullInformation => "full_information";

1;
__END__
